@@ -204,19 +204,19 @@ a!=c[b];c[b]=a;return d}};return p});
 		}
 
 		function showpopup(id) {
-		  var popup = document.getElementById("myPopupText"+id);
-		  if(popup.style.display=="inline-block"){
-		  	popup.style.display="none";
-		  }else{
-		  	popup.style.display="inline-block";
-		  }
+			var popup = document.getElementById("myPopupText"+id);
+			if(popup.style.display=="inline-block"){
+				popup.style.display="none";
+			}else{
+				popup.style.display="inline-block";
+			}
 
-		  var popupbutton = document.getElementById("myPopup"+id);
-		  if(popupbutton.innerHTML.includes(\'(+)\')){
-		 	 popupbutton.innerHTML = popupbutton.innerHTML.replace( /\(\+\)/,\'(-)\');
-		  }else{
-		  	 popupbutton.innerHTML = popupbutton.innerHTML.replace( /\(\-\)/,\'(+)\');
-		  }
+			var popupbutton = document.getElementById("myPopup"+id);
+			if(popupbutton.innerHTML.includes(\'(+)\')){
+				popupbutton.innerHTML = popupbutton.innerHTML.replace( /\(\+\)/,\'(-)\');
+			}else{
+				 popupbutton.innerHTML = popupbutton.innerHTML.replace( /\(\-\)/,\'(+)\');
+			}
 		}
 	</script>
     <style>
@@ -820,7 +820,7 @@ print '<script type="text/javascript">
 				if($coli>2){ 
 					my @ar=split(",",$k); 
 					
-						print "<td>".$ar[0];
+					print "<td>".$ar[0];
 					
 					if(scalar(@ar)>1){
 
@@ -829,8 +829,7 @@ print '<script type="text/javascript">
 							if($hiddentext ne ""){
 								$hiddentext.=", ";
 							}
-								$hiddentext.=$ar[$ii];
-							
+							$hiddentext.=$ar[$ii];
 						}
 						print '<div class="popup" onclick="showpopup(\\\''.$rowi."_".$coli.'\\\')" id="myPopup'.$rowi."_".$coli.'"><font color="blue">(+)</font></div><div class="popuptext" id="myPopupText'.$rowi."_".$coli.'"> '.$hiddentext.'</div>';
 					}
@@ -1119,7 +1118,7 @@ print '
 		    		if(genes!="" && genes.slice(-1)!=","){
 		    			genes+=",";
 		    		}
-		    		genes+=tds[i].innerHTML.replace(/([<]([^>]+)[>])/ig,"").replace(/([(]([+-]+)[)])/ig,",").replace(/[^()]+[(]([^)]+)[)]/ig,"$1,").replace(/ /ig,"").replace(/,$/ig,"").replace(/,,+/ig,",").replace(/[()]/g,"");
+		    		genes+=tds[i].innerHTML.replace(/([<]([^>]+)[>])/ig,"").replace(/[^()]+[(]([^)]+)[)]/ig,"$1,").replace(/ /ig,"").replace(/,$/ig,"").replace(/([(]([+-]+)[)])/ig,",").replace(/,,+/ig,",").replace(/[()]/g,"");
 		    	}
 		    }
 
