@@ -107,7 +107,8 @@ my $fail="";
 if (!defined($query)){
     $fail.="ERROR: no QUERY provided!\n";
 }
-if (! -e $project.".blast-graph" && ! -e $project.".proteinortho.tsv" && ! -e $project.".proteinortho-graph" && ! -d "proteinortho_cache_".$project){
+
+if (! -e $project.".blast-graph" && ! -e $project.".proteinortho.tsv" && ! -e $project.".proteinortho-graph" ){ # && ! -d "proteinortho_cache_".$project 
 	@blastglob=glob("*.blast-graph");
 	@proteinorthoglob=glob("*.proteinortho.tsv");
 	if (scalar(@blastglob)>0){
@@ -121,6 +122,7 @@ if (! -e $project.".blast-graph" && ! -e $project.".proteinortho.tsv" && ! -e $p
 	}
 }
 
+
 if($do_quotemeta){
 	$query_esc=quotemeta($query);
 	$query_esc=~s/\\([, ])/$1/;
@@ -144,14 +146,56 @@ if($fail){
 
 print STDERR "\nA short history of '"; if(scalar(@query_split)==2){print STDERR $query_split_noesc[0]."' and '".$query_split_noesc[1];}else{print STDERR $query_split_noesc[0]} print STDERR "' in '$project':\n";
 
+my $evalue=1e-5;
+my $cov=50;
+my $conn=0.1;
+my $identity=25;
+my $sim=0.95;
+if(-e $project.".info"){
+	open(my $FHinfo,"<$project.info") or die "ERROR: file not found $! $?\n";
+	while(<$FHinfo>){
+		if(/Parameter-vector.*/){
+			if(/evalue=([^,]+)/){$evalue=$1}
+			if(/coverage=([^,]+)/){$cov=$1}
+			if(/connectivity=([^,]+)/){$conn=$1}
+			if(/identity=([^,]+)/){$identity=$1}
+			if(/sim=([^,]+)/){$sim=$1}
+		}
+	}
+	close($FHinfo);
+}
+
 print STDERR "\n:::::::[ input files ]::::::::::::::::\n\n";
 #
 # input files
 #
 
 my $did_found_a_in_input=0;
+my %gene_len;
 my $did_found_b_in_input=0;
 
+for(my $v = 0 ; $v < scalar @ARGV ; $v++){
+	if($ARGViddone[$v] || $ARGV[$v] eq $query){next;}	
+	open(my $FHfasta,"<$ARGV[$v]") or die "ERROR: file not found $! $?\n";
+	my $cur_gene="";
+	my $cur_len=0;
+	while(<$FHfasta>){
+		chomp;
+		if(/^[^>]/){
+			$cur_len+=length($_);
+		}elsif(/>/){
+			if($cur_gene ne ""){$gene_len{$cur_gene}=$cur_len}
+			$cur_gene=$_;
+			$cur_gene=~s/>| .*//g;
+			$cur_len=0;
+		}
+	}
+	close($FHfasta);
+	if($cur_gene ne ""){$gene_len{$cur_gene}=$cur_len}
+}
+
+# foreach my $key (keys %gene_len){print STDERR "$key -> ".$gene_len{$key}."\n";}die;
+
 if($step eq "1" || $step eq "none" || $step eq "all"){
 
 	if ( $ARGViddone_counter != scalar(@ARGV) ){
@@ -172,8 +216,8 @@ if($step eq "1" || $step eq "none" || $step eq "all"){
 			if($num_result==0){
 				# did not found the query in this file ...
 			}elsif($num_result==1 && $did_found_a_in_input==0){
-				print STDERR "found '".$query_split_noesc[0]."' in ".$ARGV[$v].". \n";
 				$did_found_a_in_input=1;
+				print STDERR "found '".$query_split_noesc[0]."' (length=".$gene_len{$query_split_noesc[0]}.") in ".$ARGV[$v].". \n";
 				if($step ne "none"){print `proteinortho_grab_proteins.pl -E '\\b$query_split[0]\\b' $ARGV[$v]`."\n";}
 			}elsif($num_result>1){
 				print STDERR "! ERROR ! found '".$query_split_noesc[0]."' multiple times in ".$ARGV[$v].". This seems dangerous, make sure there are no duplicates present in your fasta files ! \n";
@@ -238,6 +282,22 @@ if($step eq "2" || $step eq "none" || $step eq "all"){
 		$num_a_all_blast_hits=scalar split("\n",$result);
 
 		print STDERR "the query '".$query_split_noesc[0]."' got $num_a_all_blast_hits hit(s).\n";
+
+		{
+			my $num_a_all_blast_hits_filter=scalar grep {my @a=split("\t",$_); scalar(@a)>10 && $a[10]<$evalue} split("\n",$result);
+			print STDERR "$num_a_all_blast_hits_filter/$num_a_all_blast_hits are significant (-e=$evalue).\n";
+		}
+		{
+			#print STDERR join "\n", grep {my @a=split("\t",$_); scalar(@a)>10 && exists $gene_len{$a[1]}} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
+			#die;
+			my $num_a_all_blast_hits_filter=scalar grep {my @a=split("\t",$_); scalar(@a)>10 && exists $gene_len{$a[0]} && exists $gene_len{$a[1]} && $a[3]/$gene_len{$a[0]}>$cov/100 && $a[3]/$gene_len{$a[1]}>$cov/100} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
+			print STDERR "$num_a_all_blast_hits_filter/$num_a_all_blast_hits are covered enough (-cov=$cov).\n";
+		}
+		{
+			my $num_a_all_blast_hits_filter=scalar grep {my @a=split("\t",$_); scalar(@a)>10 && $a[10]<$evalue && exists $gene_len{$a[0]} && exists $gene_len{$a[1]} && $a[3]/$gene_len{$a[0]}>$cov/100 && $a[3]/$gene_len{$a[1]}>$cov/100} map {$_=~s/^[^:]+:[0-9]+://g;$_} split("\n",$result);
+			print STDERR "$num_a_all_blast_hits_filter/$num_a_all_blast_hits are significant and covered enough (combined).\n";
+		}
+
 		if($step ne "none"){$result="# file\tline\tqseqid\tsseqid\tpident\tlength\tmismatch\tgapopen\tqstart\tqend\tsstart\tsend\tevalue\tbitscore\n".$result;$noheader=0;$last_isHeaderLine=0;$isHeaderLine=1;@spl_header=();@spl=();foreach(split("\n",$result)){processLine($_);}print "\n";}
 
 		if(scalar @query_split == 2){
@@ -295,7 +355,7 @@ print STDERR "\n:::::::[ reciprocal best hit ]::::::::\n\n";
 		$result=`grep -nH '\\b$query_split[0]\\b' $project.blast-graph 2>/dev/null`;
 		$num_a_aRBH_hits=scalar split("\n",$result);
 
-		print STDERR "the query '".$query_split_noesc[0]."' got $num_a_aRBH_hits reciprocal hit(s).\n";
+		print STDERR "the query '".$query_split_noesc[0]."' got $num_a_aRBH_hits reciprocal hit(s) with -sim=$sim.\n";
 		if($step ne "none"){$noheader=0;$last_isHeaderLine=0;$isHeaderLine=1;@spl_header=();@spl=();foreach(split("\n",`head -n2 $project.blast-graph |tail -n1| perl -lne 'chomp;s/#//g;print "# file\tline\t\$_"'`.$result)){processLine($_);}print "\n";}
 
 		if(scalar @query_split == 2){
@@ -339,7 +399,7 @@ if($step eq "3" || $step eq "none" || $step eq "all"){
 		$result=`grep -nH '\\b$query_split[0]\\b' $project.proteinortho-graph 2>/dev/null`;
 		$num_a_cluster_hits=scalar split("\n",$result);
 
-		print STDERR "the query '".$query_split_noesc[0]."' got $num_a_cluster_hits putative ortholog(s).\n";
+		print STDERR "the query '".$query_split_noesc[0]."' got $num_a_cluster_hits putative ortholog(s) with -conn=$conn.\n";
 		if($step ne "none"){$result=`echo '# file\tline\t'|tr -d '\n'; head -n2 $project.proteinortho-graph| tail -n1 | sed 's/#//g'`.$result;$noheader=0;$last_isHeaderLine=0;$isHeaderLine=1;@spl_header=();@spl=();foreach(split("\n",$result)){processLine($_);}print "\n";}
 
 		if(scalar @query_split == 2){
@@ -430,7 +490,7 @@ if(scalar @query_split == 2){
 	if($did_found_b_in_input && $did_found_a_in_input){print STDERR "Found both queries in the input files.\n"}else{print STDERR "Did found the two queries in the input files...\n\n";exit(0);}
 	if($proteinortho_cache){
 		if($num_ab_all_blast_hits){print STDERR "Both queries hit each other"}else{print STDERR "Sadly, the two queries did not hit each other using the blast algorithm...\n\n";exit(0);}
-		if($num_ab_aRBH_hits){print STDERR " AND they are adaptive reciprocal best hits too.\n"}else{print STDERR " but they are NOT adaptive reciprocal best hits...\n\n";exit(0);}
+		if($num_ab_aRBH_hits){print STDERR " AND they are adaptive reciprocal best hits.\n"}else{print STDERR " but they are NOT adaptive reciprocal best hits...\n\n";exit(0);}
 	}else{
 		if($num_ab_aRBH_hits){print STDERR "Furthermore, Both queries are adaptive reciprocal best hits.\n"}else{print STDERR "Sadly, both queries are NOT adaptive reciprocal best hits...\n\n";exit(0);}	
 	}
@@ -439,7 +499,7 @@ if(scalar @query_split == 2){
 	if($did_found_a_in_input){print STDERR "Found the query in the input files.\n"}else{print STDERR "I did NOT find the query in the input files...\n\n";exit(0);}
 	if($proteinortho_cache){
 		if($num_a_all_blast_hits){print STDERR "The query hit $num_a_all_blast_hits other protein(s)/gene(s) (blast-graph)"}else{print STDERR "the query did not hit anything (blast-graph)...\n\n";exit(0);}
-		if($num_a_aRBH_hits){print STDERR " AND $num_a_aRBH_hits of these hits are adaptive reciprocal best hits too.\n"}else{print STDERR " BUT none of these hits are adaptive reciprocal best hits...\n\n";exit(0);}
+		if($num_a_aRBH_hits){print STDERR " AND $num_a_aRBH_hits of these hits are adaptive reciprocal best hits.\n"}else{print STDERR " BUT none of these hits are adaptive reciprocal best hits...\n\n";exit(0);}
 	}else{
 		if($num_a_aRBH_hits){print STDERR "The query is part of the adaptive reciprocal best hit graph.\n"}else{print STDERR "The query is NOT part of the adaptive reciprocal best hit graph...\n\n";exit(0);}	
 	}
@@ -447,10 +507,10 @@ if(scalar @query_split == 2){
 }
 
 print STDERR "\n";
-
-print STDERR "WARNING: The project '".$project_corrected."' was not found, I automatically detected '$project' ! (Specify the project name (prefix) with -project=...)\n";
-
-print STDERR "\n";
+if($project_corrected ne ""){
+	print STDERR "WARNING: The project '".$project_corrected."' was not found, I automatically detected '$project' ! (Specify the project name (prefix) with -project=...)\n";
+	print STDERR "\n";
+}
 
 
 
